==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DoplataLimit.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class DoplataLimit extends GenericDPSObject {
    /**
     * DOPLATA_LIMIT.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * DOPLATA_LIMIT.KWOTA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwota;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DOPLATA_LIMIT.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * DOPLATA_LIMIT.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return DOPLATA_LIMIT.KWOTA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * DOPLATA_LIMIT.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DoplataLimit other = (DoplataLimit) that;
        return (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", osobaId=").append(osobaId);
        sb.append(", kwota=").append(kwota);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DoplataLimit.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class DoplataLimit extends GenericDPSObject {
    /**
     * DOPLATA_LIMIT.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * DOPLATA_LIMIT.KWOTA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwota;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DOPLATA_LIMIT.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * DOPLATA_LIMIT.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return DOPLATA_LIMIT.KWOTA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * DOPLATA_LIMIT.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DoplataLimit other = (DoplataLimit) that;
        return (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", osobaId=").append(osobaId);
        sb.append(", kwota=").append(kwota);
        sb.append("]");
        return sb.toString();
    }
}
